@@ -298,11 +298,11 @@ QString StaticMapMarker::toString() const
 
     }
 
-    ret = ret.replace(QLatin1String(", "), QLatin1String(","));
-    ret = ret.replace(QLatin1String(". "), QLatin1String("."));
-    ret = ret.replace(QLatin1Char(' '), QLatin1Char('+'));
-    ret = ret.replace(QLatin1Char('\n'), QLatin1Char(','));
-    ret = ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
+    ret.replace(QLatin1String(", "), QLatin1String(","));
+    ret.replace(QLatin1String(". "), QLatin1String("."));
+    ret.replace(QLatin1Char(' '), QLatin1Char('+'));
+    ret.replace(QLatin1Char('\n'), QLatin1Char(','));
+    ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
 
     return ret;
 
